summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codeoperation.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /umbrello/umbrello/codeoperation.h
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/codeoperation.h')
-rw-r--r--umbrello/umbrello/codeoperation.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/codeoperation.h b/umbrello/umbrello/codeoperation.h
index 5709f31a..8bdc34fd 100644
--- a/umbrello/umbrello/codeoperation.h
+++ b/umbrello/umbrello/codeoperation.h
@@ -36,7 +36,7 @@ public:
/**
* Constructors
*/
- CodeOperation ( ClassifierCodeDocument * doc , UMLOperation * tqparent,
+ CodeOperation ( ClassifierCodeDocument * doc , UMLOperation * parent,
const TQString & body = "", const TQString & comment = "");
/**
@@ -45,7 +45,7 @@ public:
virtual ~CodeOperation ( );
/**
* Get the tqparent UMLOperation of this codeoperation.
*/
UMLOperation * getParentOperation( );
@@ -45,7 +45,7 @@ public:
virtual ~CodeOperation ( );
/**
- * Get the tqparent UMLOperation of this codeoperation.
+ * Get the parent UMLOperation of this codeoperation.
*/
UMLOperation * getParentOperation( );